@@ -49,6 +49,18 @@ class S3ArchiveTest(TestCase):
         self.archive.cleanup_file(out)
         assert not path.exists(), path
 
+    def test_list_files(self):
+        keys = list(self.archive.list_files())
+        assert len(keys) == 0, keys
+        out = self.archive.archive_file(self.file)
+        keys = list(self.archive.list_files())
+        assert len(keys) == 1, keys
+        keys = list(self.archive.list_files(prefix=out[:4]))
+        assert len(keys) == 1, keys
+        assert keys[0] == out, keys
+        keys = list(self.archive.list_files(prefix="banana"))
+        assert len(keys) == 0, keys
+
     def test_delete_file(self):
         out = self.archive.archive_file(self.file)
         path = self.archive.load_file(out)
